@@ -15,11 +15,11 @@ C<Math::Geometry::Construction::Line> - line through two points
 
 =head1 VERSION
 
-Version 0.006
+Version 0.007
 
 =cut
 
-our $VERSION = '0.006';
+our $VERSION = '0.007';
 
 
 ###########################################################################
@@ -78,7 +78,7 @@ sub positions {
     return map { $_->position } $self->points;
 }
 
-sub as_svg {
+sub draw {
     my ($self, %args) = @_;
     return undef if $self->hidden;
 
@@ -106,17 +106,15 @@ sub as_svg {
 		     $self->extreme_position(-$direction)
 		     - $direction * $self->extend);
 
-    $args{parent}->line(x1    => $positions[0]->x,
-			y1    => $positions[0]->y,
-			x2    => $positions[1]->x,
-			y2    => $positions[1]->y,
-			style => $self->style_hash,
-			id    => $self->id);
-
-    $self->label_as_svg
-	(parent => $args{parent},
-	 'x'    => ($positions[0]->x + $positions[1]->x) / 2,
-	 'y'    => ($positions[0]->y + $positions[1]->y) / 2);
+    $self->construction->draw_line(x1    => $positions[0]->x,
+				   y1    => $positions[0]->y,
+				   x2    => $positions[1]->x,
+				   y2    => $positions[1]->y,
+				   style => $self->style_hash,
+				   id    => $self->id);
+    
+    $self->draw_label('x' => ($positions[0]->x + $positions[1]->x) / 2,
+		      'y' => ($positions[0]->y + $positions[1]->y) / 2);
 }
 
 ###########################################################################
